@@ -1,6 +1,6 @@
 package FSM::Basic;
 
-use 5.100.0;
+use 5.10;
 use strict;
 use warnings;
 
@@ -10,11 +10,11 @@ FSM::Basic -  Finite state machine using HASH as state definitions
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
